from setuptools import setup, find_packages

setup(
    name='busylib',
    version='0.0.1',
    description='Package name reserved',
    long_description='This package name is reserved for future use',
    url='https://github.com/yourusername/busylib',
    author='Your Name',
    author_email='your.email@example.com',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 1 - Planning',
        'Programming Language :: Python :: 3',
    ],
    python_requires='>=3.6',
)

